==> Bio-NEXUS-0.67.tar.gz: Bio-NEXUS-0.67/lib/Bio/NEXUS/CodonsBlock.pm <==
#################################################################
# CodonsBlock.pm
#################################################################
# Author: Thomas Hladish
# $Id: CodonsBlock.pm,v 1.10 2006/09/11 23:15:35 thladish Exp $

#################### START POD DOCUMENTATION ##################

=head1 NAME

Bio::NEXUS::CodonsBlock - Represents CODONS block in NEXUS file

=head1 SYNOPSIS

=head1 DESCRIPTION

Placeholding module for the CODONS block class.

=head1 COMMENTS

=head1 FEEDBACK

All feedback (bugs, feature enhancements, etc.) are greatly appreciated. 

=head1 AUTHORS

 Thomas Hladish (tjhladish at yahoo)

=head1 VERSION

$Revision: 1.10 $

=head1 METHODS

=cut

package Bio::NEXUS::CodonsBlock;

use strict;
use Data::Dumper;
use Carp;
use Bio::NEXUS::Functions;

use Bio::NEXUS; our $VERSION = $Bio::NEXUS::VERSION;

use vars qw(@ISA);
@ISA = qw(Bio::NEXUS::Block);

=head2 new

 Title   : new
 Usage   : block_object = new Bio::NEXUS::CodonsBlock();
 Function: Creates a new Bio::NEXUS::CodonsBlock object 
 Returns : Bio::NEXUS::CodonsBlock object
 Args    : 

=cut

sub new {
    my ($class) = @_;
    my $self = {};
    bless $self, $class;
    return $self;
}

sub AUTOLOAD {
    our $AUTOLOAD;
    return if $AUTOLOAD =~ /DESTROY$/;
    my $package_name = 'Bio::NEXUS::CodonBlock::';

    # The following methods are deprecated and are temporarily supported
    # via a warning and a redirection
    my %synonym_for = (

#        "${package_name}parse"      => "${package_name}_parse_tree",  # example
    );

    if ( defined $synonym_for{$AUTOLOAD} ) {
        carp "$AUTOLOAD() is deprecated; use $synonym_for{$AUTOLOAD}() instead";
        goto &{ $synonym_for{$AUTOLOAD} };
    }
    else {
        croak "ERROR: Unknown method $AUTOLOAD called";
    }
    return;
}
1;

==> Bio-NEXUS-0.72.tar.gz: Bio-NEXUS-0.72/lib/Bio/NEXUS/CodonsBlock.pm <==
#################################################################
# CodonsBlock.pm
#################################################################
# Author: Thomas Hladish
# $Id: CodonsBlock.pm,v 1.13 2007/09/21 23:09:09 rvos Exp $

#################### START POD DOCUMENTATION ##################

=head1 NAME

Bio::NEXUS::CodonsBlock - Represents CODONS block in NEXUS file

=head1 SYNOPSIS

=head1 DESCRIPTION

Placeholding module for the CODONS block class.

=head1 COMMENTS

=head1 FEEDBACK

All feedback (bugs, feature enhancements, etc.) are greatly appreciated. 

=head1 AUTHORS

 Thomas Hladish (tjhladish at yahoo)

=head1 VERSION

$Revision: 1.13 $

=head1 METHODS

=cut

package Bio::NEXUS::CodonsBlock;

use strict;
#use Data::Dumper; # XXX this is not used, might as well not import it!
#use Carp; # XXX this is not used, might as well not import it!
use Bio::NEXUS::Functions;
use Bio::NEXUS::Util::Logger;
use Bio::NEXUS::Util::Exceptions;
use vars qw(@ISA $VERSION $AUTOLOAD);
use Bio::NEXUS; $VERSION = $Bio::NEXUS::VERSION;

@ISA = qw(Bio::NEXUS::Block);
my $logger = Bio::NEXUS::Util::Logger->new();

=head2 new

 Title   : new
 Usage   : block_object = new Bio::NEXUS::CodonsBlock();
 Function: Creates a new Bio::NEXUS::CodonsBlock object 
 Returns : Bio::NEXUS::CodonsBlock object
 Args    : 

=cut

sub new {
    my ($class) = @_;
    my $self = {};
    bless $self, $class;
    return $self;
}

sub AUTOLOAD {
    return if $AUTOLOAD =~ /DESTROY$/;
    my $package_name = __PACKAGE__ . '::';

    # The following methods are deprecated and are temporarily supported
    # via a warning and a redirection
    my %synonym_for = (

#        "${package_name}parse"      => "${package_name}_parse_tree",  # example
    );

    if ( defined $synonym_for{$AUTOLOAD} ) {
        $logger->warn("$AUTOLOAD() is deprecated; use $synonym_for{$AUTOLOAD}() instead");
        goto &{ $synonym_for{$AUTOLOAD} };
    }
    else {
        Bio::NEXUS::Util::Exceptions::UnknownMethod->throw(
        	'error' => "ERROR: Unknown method $AUTOLOAD called"
        );
    }
}
1;
